$(function() {
    var $cartPopup = $( "#cart-popup" ),
        $cartPopupBody = $( "#cart-popup-body" ),
        $loader = $cartPopup.find( ".ajax-loader" ),
        $sitePrice = $( ".price" ),
        $siteQuantity = $( ".quantity" );

    // Handle 'Add Item' & 'Update Cart' form submissions
    $( document ).on( "submit", ".cart-form", function( event ) {
        event.preventDefault();

        fadeCartOut();

        $.ajax({
            type: "post",
            url: $( this ).attr( "action" ),
            data: $( this ).serialize(),
            success: function() {
                if ( $cartPopup.is( ":visible" ) ) {
                    refreshCart();
                } else {
                    openCart();
                }
            }
        });
    });

    // Handle 'Remove Item' action
    $( document ).on( "click", ".cart-remove", function( event ) {
        event.preventDefault();

        fadeCartOut();

        // Execute action by following link
        $.get( $( this ).attr( "href" ), function() {
            refreshCart();
        });
    });

    // Handle 'Continue Shopping' button
    $( document ).on( "click", ".continue-button", function() {
        $.magnificPopup.close();
    });

    function fadeCartIn() {
        $loader.fadeOut( 200 );

        $cartPopupBody.animateAuto( "height", 200, function() {
            $( this ).removeClass( "transparent" ).removeAttr( "style" );
        });
    }

    function fadeCartOut() {
        $loader.fadeIn( 200 );

        $cartPopupBody.height( $cartPopupBody.height() ).addClass( "transparent" );
    }

    function closedCartCallback() {
        $loader.removeAttr( "style" );

        $cartPopupBody.addClass( "transparent" ).empty();
    }

    function openCart() {
        $.magnificPopup.open({
            callbacks: {
                close: closedCartCallback,
                open: refreshCart
            },
            items: {
                src: $cartPopup,
                type: "inline"
            },
            mainClass: "mfp-fade",
            removalDelay: 210
        });
    }

    function refreshCart() {
        var url = cart_link + "?v=" + ( new Date().getTime() );

        // Fetch updated cart
        $.get( url, function( response ) {
            // Update popup window
            $cartPopupBody.html( response );

            fadeCartIn();

            // Update the summary on main page
            refreshCartSummary();
        });
    }

    function refreshCartSummary() {
        var price = $( "#cart_total" ).text(),
            quantity = $( "#cart_quantity" ).text();

        // Update cart totals
        $sitePrice.text( price );
        $siteQuantity.text( quantity );
    }
});


/* http://darcyclarke.me/development/fix-jquerys-animate-to-allow-auto-values-2/ */
jQuery.fn.animateAuto = function( prop, speed, callback ) {
    var elem, height, width;
    return this.each(function( i, el ) {
        el = jQuery( el ), elem = el.clone().css({
            "height": "auto",
            "width": "auto"
        }).appendTo( "body" );
        height = elem.css( "height" ),
        width = elem.css( "width" ),
        elem.remove();

        if ( prop === "height" )
            el.animate({
                "height": height
            }, speed, callback );
        else if ( prop === "width" )
            el.animate({
                "width": width
            }, speed, callback );
        else if ( prop === "both" )
            el.animate({
                "width": width,
                "height": height
            }, speed, callback );
    });
};
